import { timerify } from '../../util/Performance.js';
import { hasDependency, load } from '../../util/plugin.js';
import { isConfigurationOutput } from './types.js';
export const NAME = 'Graphql Codegen';
export const ENABLERS = [/^@graphql-codegen\//];
export const PACKAGE_JSON_PATH = 'codegen';
export const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
export const CONFIG_FILE_PATTERNS = ['codegen.{ts,js,json,yml,mjs,cts}', 'package.json'];
const findPluginDependencies = async (configFilePath, options) => {
    const { manifest, isProduction } = options;
    if (isProduction)
        return [];
    const localConfig = configFilePath.endsWith('package.json')
        ? manifest[PACKAGE_JSON_PATH]
        : await load(configFilePath);
    if (!localConfig)
        return [];
    const generateSet = Object.values(localConfig.generates);
    const configurationOutput = generateSet.filter(isConfigurationOutput);
    const presets = configurationOutput
        .map(configOutput => (configOutput.preset ? configOutput.preset : undefined))
        .filter((preset) => typeof preset === 'string')
        .map(presetName => `@graphql-codegen/${presetName}${presetName.endsWith('-preset') ? '' : '-preset'}`);
    const flatPlugins = generateSet
        .filter((config) => !isConfigurationOutput(config))
        .map(item => Object.keys(item))
        .flat()
        .map(plugin => `@graphql-codegen/${plugin}`);
    const nestedPlugins = configurationOutput
        .map(configOutput => (configOutput.plugins ? configOutput.plugins : []))
        .flat()
        .map(plugin => `@graphql-codegen/${plugin}`);
    return [...presets, ...flatPlugins, ...nestedPlugins];
};
export const findDependencies = timerify(findPluginDependencies);
