import { timerify } from '../../util/Performance.js';
import { hasDependency, load } from '../../util/plugin.js';
import { toEntryPattern } from '../../util/protocols.js';
import { toEntryPatterns } from '../playwright/index.js';
export const NAME = 'Playwright for components';
export const ENABLERS = [/^@playwright\/experimental-ct-/];
export const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
export const CONFIG_FILE_PATTERNS = ['playwright-ct.config.{js,ts}', 'playwright/index.{js,ts,jsx,tsx}'];
export const ENTRY_FILE_PATTERNS = ['**/*.@(spec|test).?(c|m)[jt]s?(x)'];
const findPlaywrightCTDependencies = async (configFilePath, options) => {
    const { cwd, config } = options;
    const localConfig = await load(configFilePath);
    if (localConfig) {
        const projects = localConfig.projects ? [localConfig, ...localConfig.projects] : [localConfig];
        const patterns = projects.flatMap(config => toEntryPatterns(config.testMatch, cwd, configFilePath, config));
        if (patterns.length > 0)
            return patterns;
    }
    return (config?.entry ?? ENTRY_FILE_PATTERNS).map(toEntryPattern);
};
export const findDependencies = timerify(findPlaywrightCTDependencies);
