import { timerify } from '../../util/Performance.js';
import { hasDependency, load } from '../../util/plugin.js';
import { toEntryPattern } from '../../util/protocols.js';
import { getEnvPackageName, getExternalReporters } from './helpers.js';
export const NAME = 'Vitest';
export const ENABLERS = ['vitest'];
export const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
export const CONFIG_FILE_PATTERNS = ['vitest.config.ts', 'vitest.{workspace,projects}.{ts,js,json}'];
export const ENTRY_FILE_PATTERNS = ['**/*.{test,spec}.?(c|m)[jt]s?(x)'];
const findConfigDependencies = (localConfig, options) => {
    const { isProduction, config } = options;
    const testConfig = localConfig.test;
    const entryPatterns = (config?.entry ?? testConfig?.include ?? ENTRY_FILE_PATTERNS).map(toEntryPattern);
    if (!testConfig || isProduction)
        return entryPatterns;
    const environments = testConfig.environment ? [getEnvPackageName(testConfig.environment)] : [];
    const reporters = getExternalReporters(testConfig.reporters);
    const coverage = testConfig.coverage ? [`@vitest/coverage-${testConfig.coverage.provider ?? 'v8'}`] : [];
    const setupFiles = testConfig.setupFiles ? [testConfig.setupFiles].flat() : [];
    const globalSetup = testConfig.globalSetup ? [testConfig.globalSetup].flat() : [];
    return [...entryPatterns, ...environments, ...reporters, ...coverage, ...setupFiles, ...globalSetup];
};
export const findVitestDependencies = async (localConfig, options) => {
    if (!localConfig)
        return [];
    if (typeof localConfig === 'function') {
        const dependencies = new Set();
        for (const command of ['dev', 'serve', 'build']) {
            for (const mode of ['development', 'production']) {
                const config = await localConfig({ command, mode, ssrBuild: undefined });
                findConfigDependencies(config, options).forEach(dependency => dependencies.add(dependency));
            }
        }
        return Array.from(dependencies);
    }
    if (!localConfig.test)
        return [];
    return findConfigDependencies(localConfig, options);
};
const findVitestWorkspaceDependencies = async (configFilePath, options) => {
    const localConfig = await load(configFilePath);
    const dependencies = new Set();
    for (const config of [localConfig].flat()) {
        if (config && typeof config !== 'string') {
            (await findVitestDependencies(config, options)).forEach(dependency => dependencies.add(dependency));
        }
    }
    return Array.from(dependencies);
};
export const findDependencies = timerify(findVitestWorkspaceDependencies);
